==> alg-alg-1.56.74-sources.jar: cn/com/duiba/nezha/alg/alg/vo/adx/pd/AdxPdDecisionResultDo.java <==
package cn.com.duiba.nezha.alg.alg.vo.adx.pd;


import java.io.Serializable;

/**
 * PD决策出参对象
 */
public class AdxPdDecisionResultDo implements Serializable {

    private static final long serialVersionUID = -6726710047838005037L;

    /**
     * 推荐创意ID
     */
    private Long ideaId;

    /**
     * 是否放弃(0: 不放弃；1：放弃)
     */
    private Integer isGiveUp;

    /**
     * 策略
     */
    private String strategy;

    /**
     * level
     */
    private String level;

    /**
     * 点击价值分层
     */
    private Integer clickValueLevel;

    /**
     * 创意点击率-预估
     */
    private Double preCtr;

    /**
     * 创意点击率-统计(近20min)
     */
    private Double statCtr;

    /**
     * 创意点击价值-预估（TF模型预估）
     */
    private Double preClickValue;

    /**
     * 创意点击价值-预估（预发券预估）
     */
    private Double predClickValue;

    /**
     * 创意点击价值-统计(近20min，分/单次点击)
     */
    private Double statClickValue;

    /**
     * 资源位统计CTR(近20min)
     */
    private Double statCtrResource;

    /**
     * 资源位统计点击价值(近20min，分/单次点击)
     */
    private Double statClickValueResource;

    /**
     * 点击价值纠偏因子
     */
    private Double clickValueRectifyFactor;

    /**
     * 放弃原因类型
     */
    private Long giveUpType;


    public Long getIdeaId() {
        return ideaId;
    }

    public void setIdeaId(Long ideaId) {
        this.ideaId = ideaId;
    }

    public Integer getIsGiveUp() {
        return isGiveUp;
    }

    public void setIsGiveUp(Integer isGiveUp) {
        this.isGiveUp = isGiveUp;
    }

    public String getStrategy() {
        return strategy;
    }

    public void setStrategy(String strategy) {
        this.strategy = strategy;
    }

    public String getLevel() {
        return level;
    }

    public void setLevel(String level) {
        this.level = level;
    }

    public Integer getClickValueLevel() {
        return clickValueLevel;
    }

    public void setClickValueLevel(Integer clickValueLevel) {
        this.clickValueLevel = clickValueLevel;
    }

    public Double getPreCtr() {
        return preCtr;
    }

    public void setPreCtr(Double preCtr) {
        this.preCtr = preCtr;
    }

    public Double getStatCtr() {
        return statCtr;
    }

    public void setStatCtr(Double statCtr) {
        this.statCtr = statCtr;
    }

    public Double getPreClickValue() {
        return preClickValue;
    }

    public void setPreClickValue(Double preClickValue) {
        this.preClickValue = preClickValue;
    }

    public Double getPredClickValue() { return predClickValue; }

    public void setPredClickValue(Double predClickValue) { this.predClickValue = predClickValue; }

    public Double getStatClickValue() {
        return statClickValue;
    }

    public void setStatClickValue(Double statClickValue) {
        this.statClickValue = statClickValue;
    }

    public Double getStatCtrResource() {
        return statCtrResource;
    }

    public void setStatCtrResource(Double statCtrResource) {
        this.statCtrResource = statCtrResource;
    }

    public Double getStatClickValueResource() {
        return statClickValueResource;
    }

    public void setStatClickValueResource(Double statClickValueResource) {
        this.statClickValueResource = statClickValueResource;
    }

    public Double getClickValueRectifyFactor() {
        return clickValueRectifyFactor;
    }

    public void setClickValueRectifyFactor(Double clickValueRectifyFactor) {
        this.clickValueRectifyFactor = clickValueRectifyFactor;
    }

    public Long getGiveUpType() {
        return giveUpType;
    }

    public void setGiveUpType(Long giveUpType) {
        this.giveUpType = giveUpType;
    }
}

==> alg-alg-2.14.0-20200507.034653-1-sources.jar: cn/com/duiba/nezha/alg/alg/vo/adx/pd/AdxPdDecisionResultDo.java <==
package cn.com.duiba.nezha.alg.alg.vo.adx.pd;


/**
 * PD决策出参对象
 */
public class AdxPdDecisionResultDo {

    /**
     * 推荐创意ID
     */
    private Long ideaId;

    /**
     * 是否放弃(0: 不放弃；1：放弃)
     */
    private Integer isGiveUp;

    /**
     * 策略
     */
    private String strategy;

    /**
     * level
     */
    private String level;

    /**
     * 点击价值分层
     */
    private Integer clickValueLevel;

    /**
     * 创意点击率-预估
     */
    private Double preCtr;

    /**
     * 创意点击率-统计
     */
    private Double statCtr;

    /**
     * 创意点击价值-预估
     */
    private Double preClickValue;

    /**
     * 创意点击价值-统计
     */
    private Double statClickValue;

    /**
     * 点击价值纠偏因子
     */
    private Double clickValueRectifyFactor;

    /**
     * 放弃原因类型
     */
    private Long giveUpType;



    public Long getIdeaId() {
        return ideaId;
    }

    public void setIdeaId(Long ideaId) {
        this.ideaId = ideaId;
    }

    public Integer getIsGiveUp() {
        return isGiveUp;
    }

    public void setIsGiveUp(Integer isGiveUp) {
        this.isGiveUp = isGiveUp;
    }

    public String getStrategy() {
        return strategy;
    }

    public void setStrategy(String strategy) {
        this.strategy = strategy;
    }

    public String getLevel() {
        return level;
    }

    public void setLevel(String level) {
        this.level = level;
    }

    public Integer getClickValueLevel() {
        return clickValueLevel;
    }

    public void setClickValueLevel(Integer clickValueLevel) {
        this.clickValueLevel = clickValueLevel;
    }

    public Double getPreCtr() {
        return preCtr;
    }

    public void setPreCtr(Double preCtr) {
        this.preCtr = preCtr;
    }

    public Double getStatCtr() {
        return statCtr;
    }

    public void setStatCtr(Double statCtr) {
        this.statCtr = statCtr;
    }

    public Double getPreClickValue() {
        return preClickValue;
    }

    public void setPreClickValue(Double preClickValue) {
        this.preClickValue = preClickValue;
    }

    public Double getStatClickValue() {
        return statClickValue;
    }

    public void setStatClickValue(Double statClickValue) {
        this.statClickValue = statClickValue;
    }

    public Double getClickValueRectifyFactor() {
        return clickValueRectifyFactor;
    }

    public void setClickValueRectifyFactor(Double clickValueRectifyFactor) {
        this.clickValueRectifyFactor = clickValueRectifyFactor;
    }

    public Long getGiveUpType() {
        return giveUpType;
    }

    public void setGiveUpType(Long giveUpType) {
        this.giveUpType = giveUpType;
    }
}
